""" Dictionary of Preknown Words 
Copyright 2018(c), Andrew Ferlitsch
"""

class Vocabulary(object):
    """ Predefined Vocabulary """
    UNTAG           = 0     # Not tagged
    NUMBER          = 1     # Is a number
    DATE            = 2     # Is a date
    CONJUNCTION     = 3     # conjunction
    ARTICLE         = 4     # article
    DEMONSTRATIVE   = 5     # Demonstrative
    PREPOSITION     = 6     # Prepositions
    QUESTION        = 7     # Question words
    PRONOUN         = 8     # Pronouns
    SSN             = 9     # Social Security Number
    TELEPHONE       = 10    # Telephone Number
    NAME            = 11    # Proper Names
    ADDRESS         = 12    # Street Addresses
    QUANTIFIER      = 13    # Size words
    ACRONYM         = 14    # Acronym
    MALE            = 15    # Gender
    FEMALE          = 16    # Gender
    TRANSGENDER     = 17    # Gender
    POSITIVE		= 18	# Sentiment
    NEGATIVE		= 19	# Sentiment
    DOB             = 20    # Date of Birth
    PORTER          = 21    # Porter Stopwords
    ABBR            = 22    # Abbreviations
    PUNCT           = 23    # Punctuation
    SYMBOL          = 24    # Symbol
    UNIT            = 25    # Unit of Measure
    MUNIT           = 26    # Multiplying unit (e.g., 10 million = 10,000,000)
    STREET_NUM      = 27    # Street Number in Address
    STREET_DIR      = 28    # Street Direction in Address
    STREET_NAME     = 29    # Street Name in Address
    STREET_TYPE     = 30    # Street Type in Address
    CITY            = 31    # City
    STATE           = 32    # State
    TITLE           = 33    # Proper Name Title
    POSTAL          = 34    # Postal Code
    POB             = 35    # Post Office Box
    SAC             = 36    # Secondary Address Component (e.g., Apt)
    STATION         = 37    # Delivery Station (Canada)
    MEASUREMENT     = 38    # Measurement
    TELEPHONE_HOME  = 39    # Home Telephone
    TELEPHONE_WORK  = 40    # Work/Office Telephone
    TELEPHONE_CELL  = 41    # Cell/Mobile Telephone
    TELEPHONE_FAX   = 42    # FAX number
    AGE             = 43    # Age
    
    # Special Markers
    PAD             = '<PAD>'
    OUT             = '<OUT>'
    SOS             = '<SOS>'
    EOS             = '<EOS>'
    EMP             = '<EMP>'
    NEG             = '<NEG>'
    POS             = '<POS>'

vocab = {'a'            : { 'tag': [  Vocabulary.ARTICLE ], 'lemma': None },
         'an'           : { 'tag': [  Vocabulary.ARTICLE ], 'lemma': None },
         'the'          : { 'tag': [  Vocabulary.ARTICLE ], 'lemma': None },
         'all'          : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': ['1']  },
         'any'          : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': None },
         'both'         : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': None },
         'big'          : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': None },
         'empty'        : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': ['0']  },    
         'few'          : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': None },
         'full'         : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': ['1']  },    
         'half'         : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': ['0.5']},    
         'high'         : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': None },
         'large'        : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': None },
         'least'        : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': None },
         'less'         : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': None },
         'little'       : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': None },
         'long'         : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': None },
         'low'          : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': None },
         'many'         : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': None },
         'more'         : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': None },
         'most'         : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': None },
         'much'         : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': None },
         'non'          : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': None },
         'none'         : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': ['0'] },
         'often'        : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': None },
         'once'         : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': ['1']  },
         'part'         : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': None },   
         'partial'      : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': None },    
         'quarter'      : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': ['0.25'] }, 
         'several'      : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': None },   
         'short'        : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': None },
         'small'        : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': None },
         'some'         : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': None },
         'tall'         : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': None },
         'tiny'         : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': None },
         'whole'        : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': ['1']  }, 
         'middle'       : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': ['0.5']},
         'last'         : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': None },
         'above'        : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'across'       : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'after'        : { 'tag': [  Vocabulary.PREPOSITION, Vocabulary.CONJUNCTION ], 'lemma': None },
         'at'           : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'before'       : { 'tag': [  Vocabulary.PREPOSITION, Vocabulary.CONJUNCTION ], 'lemma': None },
         'behind'       : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'below'        : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'beneath'      : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'between'      : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'besides'      : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'bottom'       : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'by'           : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'down'         : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'far'          : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'from'         : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'here'         : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'in'           : { 'tag': [  Vocabulary.PREPOSITION, Vocabulary.UNIT ], 'lemma': ['in', 'inch'] },
         'inside'       : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'instead'      : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'into'         : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'near'         : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'next'         : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'of'           : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'on'           : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'out'          : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'outside'      : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'over'         : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'there'        : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'through'      : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'throughout'   : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'to'           : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'top'          : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'thru'         : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'under'        : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'underneath'   : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'upon'         : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'up'           : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'with'         : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'within'       : { 'tag': [  Vocabulary.PREPOSITION ], 'lemma': None },
         'also'         : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'although'     : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'and'          : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'as'           : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'because'      : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'but'          : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'consequently' : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': ['consequently'] },
         'either'       : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'for'          : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'furthermore'  : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'hence'        : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'however'      : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'if'           : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'indeed'       : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'likewise'     : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'meanwhile'    : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'neither'      : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'nor'          : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'or'           : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'otherwise'    : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'since'        : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'so'           : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'still'        : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'such'         : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'than'         : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'therefore'    : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'though'       : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'thus'         : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'unless'       : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'until'        : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'while'        : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'yet'          : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'where'        : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'wherever'     : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'whether'      : { 'tag': [  Vocabulary.CONJUNCTION ], 'lemma': None },
         'this'         : { 'tag': [  Vocabulary.DEMONSTRATIVE ], 'lemma': None },
         'that'         : { 'tag': [  Vocabulary.DEMONSTRATIVE ], 'lemma': None },
         'these'        : { 'tag': [  Vocabulary.DEMONSTRATIVE ], 'lemma': None },
         'those'        : { 'tag': [  Vocabulary.DEMONSTRATIVE ], 'lemma': None },
         'anybody'      : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'anyone'       : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'anything'     : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'each'         : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'everybody'    : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'everyone'     : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'everything'   : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'he'           : { 'tag': [  Vocabulary.PRONOUN, Vocabulary.MALE ], 'lemma': ['he', 'he'] },
         'her'          : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'herself'      : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'his'          : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'him'          : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'himself'      : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'i'            : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'it'           : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'its'          : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'itself'       : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'me'           : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'my'           : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'myself'       : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'nobody'       : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'our'          : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'ourself'      : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'oneself'      : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'self'         : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'she'          : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'somebody'     : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'someone'      : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'something'    : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'them'         : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'they'         : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'their'        : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'thee'         : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'themselves'   : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'thine'        : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'thou'         : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'thyself'      : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'us'           : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'we'           : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'whoever'      : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'whom'         : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'whomever'     : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'whichever'    : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'you'          : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'your'         : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'yourself'     : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'ye'           : { 'tag': [  Vocabulary.PRONOUN ], 'lemma': None },
         'how'          : { 'tag': [  Vocabulary.QUESTION ], 'lemma': None },
         'what'         : { 'tag': [  Vocabulary.QUESTION ], 'lemma': None },
         'where'        : { 'tag': [  Vocabulary.QUESTION ], 'lemma': None },
         'when'         : { 'tag': [  Vocabulary.QUESTION ], 'lemma': None },
         'who'          : { 'tag': [  Vocabulary.QUESTION ], 'lemma': None },
         'which'        : { 'tag': [  Vocabulary.QUESTION ], 'lemma': None },
         'why'          : { 'tag': [  Vocabulary.QUESTION ], 'lemma': None },
         'mr'           : { 'tag': [  Vocabulary.TITLE ], 'lemma': [ 'mr' ] },
         'mrs'          : { 'tag': [  Vocabulary.TITLE ], 'lemma': None },
         'ms'           : { 'tag': [  Vocabulary.TITLE ], 'lemma': None },
         'jr'           : { 'tag': [  Vocabulary.TITLE ], 'lemma': ['junior'] },
         'sr'           : { 'tag': [  Vocabulary.TITLE ], 'lemma': ['senior'] },
         'dr'           : { 'tag': [  Vocabulary.TITLE ], 'lemma': [ "doctor" ] },
         'doctor'       : { 'tag': [  Vocabulary.TITLE ], 'lemma': ['doctor'] },
         'md'           : { 'tag': [  Vocabulary.TITLE ], 'lemma': ['medical doctor'] },
         'phd'          : { 'tag': [  Vocabulary.TITLE ], 'lemma': None },
         'rn'           : { 'tag': [  Vocabulary.TITLE ], 'lemma': ['nurse'] },
         'nurse'        : { 'tag': [  Vocabulary.TITLE ], 'lemma': ['nurse'] },
         'dentist'      : { 'tag': [  Vocabulary.TITLE ], 'lemma': ['dentist'] },
         'attorney'     : { 'tag': [  Vocabulary.TITLE ], 'lemma': ['attorney'] },
         'atty'         : { 'tag': [  Vocabulary.TITLE ], 'lemma': ['attorney'] },
         'prof'         : { 'tag': [  Vocabulary.TITLE ], 'lemma': ['professor'] },
         'professor'    : { 'tag': [  Vocabulary.TITLE ], 'lemma': ['professor'] },
         'vp'           : { 'tag': [  Vocabulary.TITLE ], 'lemma': ['vice president'] },
         'ceo'          : { 'tag': [  Vocabulary.TITLE ], 'lemma': ['chief executive officier'] },      
         'coo'          : { 'tag': [  Vocabulary.TITLE ], 'lemma': None },     
         'cto'          : { 'tag': [  Vocabulary.TITLE ], 'lemma': None },     
         'cio'          : { 'tag': [  Vocabulary.TITLE ], 'lemma': None },    
         'mayor'        : { 'tag': [  Vocabulary.TITLE ], 'lemma': None },  
         'councilman'   : { 'tag': [  Vocabulary.TITLE ], 'lemma': None },   
         'sheriff'      : { 'tag': [  Vocabulary.TITLE ], 'lemma': None },   
         'senator'      : { 'tag': [  Vocabulary.TITLE ], 'lemma': None },   
         'congressman'  : { 'tag': [  Vocabulary.TITLE ], 'lemma': None },   
         'governor'     : { 'tag': [  Vocabulary.TITLE ], 'lemma': None },  
         'president'    : { 'tag': [  Vocabulary.TITLE ], 'lemma': None },   
         'treasurer'    : { 'tag': [  Vocabulary.TITLE ], 'lemma': None },  
         'sgt'          : { 'tag': [  Vocabulary.TITLE ], 'lemma': ['sergeant'] }, 
         'sergeant'     : { 'tag': [  Vocabulary.TITLE ], 'lemma': None }, 
         'colonel'      : { 'tag': [  Vocabulary.TITLE ], 'lemma': None },  
         'cpl'          : { 'tag': [  Vocabulary.TITLE ], 'lemma': ['corporal'] },  
         'corporal'     : { 'tag': [  Vocabulary.TITLE ], 'lemma': None }, 
         'lieutenant'   : { 'tag': [  Vocabulary.TITLE ], 'lemma': None },  
         'cmdr'         : { 'tag': [  Vocabulary.TITLE ], 'lemma': ['commander'] },   
         'commander'    : { 'tag': [  Vocabulary.TITLE ], 'lemma': None },  
         'capt'         : { 'tag': [  Vocabulary.TITLE ], 'lemma': ['captain'] },   
         'captain'      : { 'tag': [  Vocabulary.TITLE ], 'lemma': None },  
         'vice'         : { 'tag': [  Vocabulary.TITLE ], 'lemma': None },  
         'male'         : { 'tag': [  Vocabulary.MALE ], 'lemma': None },
         'man'          : { 'tag': [  Vocabulary.MALE ], 'lemma': None },
         'men'          : { 'tag': [  Vocabulary.MALE ], 'lemma': None },
         'boy'          : { 'tag': [  Vocabulary.MALE ], 'lemma': None },
         'guy'          : { 'tag': [  Vocabulary.MALE ], 'lemma': None },
         'dude'         : { 'tag': [  Vocabulary.MALE ], 'lemma': None },
         'dad'          : { 'tag': [  Vocabulary.MALE ], 'lemma': ['father'] },   
         'daddy'        : { 'tag': [  Vocabulary.MALE ], 'lemma': ['father'] },  
         'father'       : { 'tag': [  Vocabulary.MALE ], 'lemma': ['father'] }, 
         'papa'         : { 'tag': [  Vocabulary.MALE ], 'lemma': ['father'] },
         'son'          : { 'tag': [  Vocabulary.MALE ], 'lemma': None },
         'brother'      : { 'tag': [  Vocabulary.MALE ], 'lemma': None },
         'uncle'        : { 'tag': [  Vocabulary.MALE ], 'lemma': None },
         'gent'         : { 'tag': [  Vocabulary.MALE ], 'lemma': None },
         'gentleman'    : { 'tag': [  Vocabulary.MALE ], 'lemma': None },
         'gentlemen'    : { 'tag': [  Vocabulary.MALE ], 'lemma': None },
         'bro'          : { 'tag': [  Vocabulary.MALE ], 'lemma': ['brother'] },
         'sir'          : { 'tag': [  Vocabulary.MALE ], 'lemma': None },  
         'grandfather'  : { 'tag': [  Vocabulary.MALE ], 'lemma': None },   
         'grandpa'      : { 'tag': [  Vocabulary.MALE ], 'lemma': ['grandfather'] }, 
         'stepbrother'  : { 'tag': [  Vocabulary.MALE ], 'lemma': None },   
         'stepfather'   : { 'tag': [  Vocabulary.MALE ], 'lemma': None },    
         'stepdad'      : { 'tag': [  Vocabulary.MALE ], 'lemma': None },     
         'stepson'      : { 'tag': [  Vocabulary.MALE ], 'lemma': None },     
         'husband'      : { 'tag': [  Vocabulary.MALE ], 'lemma': None }, 
         'female'       : { 'tag': [  Vocabulary.FEMALE ], 'lemma': None },
         'woman'        : { 'tag': [  Vocabulary.FEMALE ], 'lemma': None },
         'women'        : { 'tag': [  Vocabulary.FEMALE ], 'lemma': None },
         'girl'         : { 'tag': [  Vocabulary.FEMALE ], 'lemma': None },
         'gal'          : { 'tag': [  Vocabulary.FEMALE, Vocabulary.UNIT ], 'lemma': ['gal', 'gallon'] },
         'mom'          : { 'tag': [  Vocabulary.FEMALE ], 'lemma': ['mother'] }, 
         'mommy'        : { 'tag': [  Vocabulary.FEMALE ], 'lemma': ['mother'] }, 
         'mother'       : { 'tag': [  Vocabulary.FEMALE ], 'lemma': ['mother'] }, 
         'momma'        : { 'tag': [  Vocabulary.FEMALE ], 'lemma': ['mother'] },
         'sister'       : { 'tag': [  Vocabulary.FEMALE ], 'lemma': None },
         'aunt'         : { 'tag': [  Vocabulary.FEMALE ], 'lemma': None },
         'auntie'       : { 'tag': [  Vocabulary.FEMALE ], 'lemma': ['aunt'] },
         'aunty'        : { 'tag': [  Vocabulary.FEMALE ], 'lemma': ['aunt'] },
         'lady'         : { 'tag': [  Vocabulary.FEMALE ], 'lemma': None }, 
         'sis'          : { 'tag': [  Vocabulary.FEMALE ], 'lemma': ['sister'] },
         'madam'        : { 'tag': [  Vocabulary.FEMALE ], 'lemma': None },
         'daughter'     : { 'tag': [  Vocabulary.FEMALE ], 'lemma': None },
         'grandmother'  : { 'tag': [  Vocabulary.FEMALE ], 'lemma': None },
         'grandma'      : { 'tag': [  Vocabulary.FEMALE ], 'lemma': ['grandmother'] },
         'granny'       : { 'tag': [  Vocabulary.FEMALE ], 'lemma': ['grandmother'] },
         'grannie'      : { 'tag': [  Vocabulary.FEMALE ], 'lemma': ['grandmother'] },
         'stepsister'   : { 'tag': [  Vocabulary.FEMALE ], 'lemma': None },
         'stepmother'   : { 'tag': [  Vocabulary.FEMALE ], 'lemma': None },
         'stepmom'      : { 'tag': [  Vocabulary.FEMALE ], 'lemma': None },
         'stepsister'   : { 'tag': [  Vocabulary.FEMALE ], 'lemma': None },
         'wife'         : { 'tag': [  Vocabulary.FEMALE ], 'lemma': None },
         'transgender'  : { 'tag': [  Vocabulary.TRANSGENDER ], 'lemma': None },  
         'ladyboy'      : { 'tag': [  Vocabulary.TRANSGENDER ], 'lemma': None },   
         'sissy'        : { 'tag': [  Vocabulary.TRANSGENDER ], 'lemma': None },   
         'shemale'      : { 'tag': [  Vocabulary.TRANSGENDER ], 'lemma': None },   
         'tg'           : { 'tag': [  Vocabulary.TRANSGENDER ], 'lemma': None },    
         'tranny'       : { 'tag': [  Vocabulary.TRANSGENDER ], 'lemma': None },  
         'crossdresser' : { 'tag': [  Vocabulary.TRANSGENDER ], 'lemma': None },    
         'amaze'        : { 'tag': [  Vocabulary.POSITIVE ], 'lemma': None },   
         'awesome'      : { 'tag': [  Vocabulary.POSITIVE ], 'lemma': None },   
         'beauty'       : { 'tag': [  Vocabulary.POSITIVE ], 'lemma': None },
         'best'         : { 'tag': [  Vocabulary.POSITIVE ], 'lemma': ['best'] },
         'better'       : { 'tag': [  Vocabulary.POSITIVE ], 'lemma': ['better'] },  
         'cool'         : { 'tag': [  Vocabulary.POSITIVE ], 'lemma': None }, 
         'excellent'    : { 'tag': [  Vocabulary.POSITIVE ], 'lemma': None },
         'fair'         : { 'tag': [  Vocabulary.POSITIVE ], 'lemma': None },
         'favorite'     : { 'tag': [  Vocabulary.POSITIVE ], 'lemma': None }, 
         'fantastic'    : { 'tag': [  Vocabulary.POSITIVE ], 'lemma': None }, 
         'fun'          : { 'tag': [  Vocabulary.POSITIVE ], 'lemma': None }, 
         'good'         : { 'tag': [  Vocabulary.POSITIVE ], 'lemma': None }, 
         'great'        : { 'tag': [  Vocabulary.POSITIVE ], 'lemma': None }, 
         'like'         : { 'tag': [  Vocabulary.POSITIVE ], 'lemma': None },
         'love'         : { 'tag': [  Vocabulary.POSITIVE ], 'lemma': None }, 
         'luv'          : { 'tag': [  Vocabulary.POSITIVE ], 'lemma': "love" }, 
         'nice'         : { 'tag': [  Vocabulary.POSITIVE ], 'lemma': None },  
         'perfect'      : { 'tag': [  Vocabulary.POSITIVE ], 'lemma': None },    
         'pleasant'     : { 'tag': [  Vocabulary.POSITIVE ], 'lemma': None }, 
         'recommend'    : { 'tag': [  Vocabulary.POSITIVE ], 'lemma': None }, 
         'superb'       : { 'tag': [  Vocabulary.POSITIVE ], 'lemma': None },    
         'yes'          : { 'tag': [  Vocabulary.POSITIVE ], 'lemma': None }, 
         'wonderful'    : { 'tag': [  Vocabulary.POSITIVE ], 'lemma': None }, 
         'bad'          : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': None }, 
         'break'        : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': None }, 
         'crap'         : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': None },
         'dead'         : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': None }, 
         'disgust'      : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': None }, 
         'dumb'         : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': None },   
         'break'        : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': None }, 
         'idiot'        : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': None },  
         'idiotic'      : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': ['idiot'] }, 
         'lousy'        : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': None }, 
         'no'           : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': None }, 
         'not'          : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': None }, 
         'nothing'      : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': None }, 
         'never'        : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': None },  
         'poor'         : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': None }, 
         'shit'         : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': None }, 
         'shithole'     : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': ['shit'] },  
         'stink'        : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': None }, 
         'stupid'       : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': None },  
         'suck'         : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': None }, 
         'terrible'     : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': None }, 
         'ugly'         : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': None },  
         'worse'        : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': None },    
         'worst'        : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': ['worse'] },       
         'bore'         : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': ['bore'] },
         'appall'       : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': ['appall']},
         'horror'       : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': ['horror']},
         'horrible'     : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': ['horror']},
         'aboard'       : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'about'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'again'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'against'      : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'almost'       : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'alone'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'along'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'alongside'    : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'already'      : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'alway'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'always'       : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'am'           : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'admid'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'admist'       : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'among'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'amongst'      : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'another'      : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'anti'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'anywhere'     : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'area'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'around'       : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'are'          : { 'tag': [  Vocabulary.PORTER ], 'lemma': ['is'] },
         'ask'          : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'astride'      : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'away'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'back'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'bar'          : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'be'           : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'became'       : { 'tag': [  Vocabulary.PORTER ], 'lemma': ['become'] },
         'become'       : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'begin'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'being'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'been'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'beyond'       : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'came'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': ['come'] },
         'come'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'can'          : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'cannot'       : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'could'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': ['can'] },
         'certain'      : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'circa'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'clear'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'consider'     : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'concern'      : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'despite'      : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'did'          : { 'tag': [  Vocabulary.PORTER ], 'lemma': ['do'] },
         'differ'       : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'do'           : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'does'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': ['do'] },
         'during'       : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'end'          : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'enough'       : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'even'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'ever'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'every'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'except'       : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'exclude'      : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'felt'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'find'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'follow'       : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'fully'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'further'      : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'gave'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': ['give'] },
         'general'      : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'get'          : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'give'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'given'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': ['give'] },
         'go'           : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'got'          : { 'tag': [  Vocabulary.PORTER ], 'lemma': ['get'] },
         'group'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'had'          : { 'tag': [  Vocabulary.PORTER ], 'lemma': ['has'] },
         'has'          : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'have'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': ['has'] },
         'is'           : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'ilk'          : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'include'      : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'important'    : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'interest'     : { 'tag': [  Vocabulary.PORTER ], 'lemma': ['interest'] },
         'just'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'keep'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'kind'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'knew'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': ['know'] },
         'know'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'known'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'later'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'let'          : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'make'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'may'          : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'made'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'member'       : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'might'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'mine'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'minus'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'naught'       : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'necessary'    : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'need'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'new'          : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'notwithstand' : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'now'          : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'nowhere'      : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'number'       : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'off'          : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'only'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'old'          : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'onto'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'open'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'opposite'     : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'order'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'other'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'ought'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'own'          : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'past'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'pending'      : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'per'          : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'perhaps'      : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'plus'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'point'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'possible'     : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'present'      : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'problem'      : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'put'          : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'quite'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'rather'       : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'really'       : { 'tag': [  Vocabulary.PORTER ], 'lemma': ['really'] },
         'regard'       : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'room'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'round'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'said'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'same'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'say'          : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'save'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'saw'          : { 'tag': [  Vocabulary.PORTER ], 'lemma': ['see'] },
         'see'          : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'seen'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': ['see'] },
         'seem'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'shall'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'should'       : { 'tag': [  Vocabulary.PORTER ], 'lemma': ['shall'] },
         'show'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'side'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'somewhat'     : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'somewhere'    : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'state'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'suchlike'     : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'sundry'       : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'sure'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'take'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'think'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'thought'      : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'thing'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'till'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'today'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'together'     : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'too'          : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'turn'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'toward'       : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'took'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': ['take'] },
         'twain'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'unlike'       : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'use'          : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'various'      : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'versus'       : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'was'          : { 'tag': [  Vocabulary.PORTER ], 'lemma': ['is'] },
         'very'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'via'          : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'visavis'      : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'way'          : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'want'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'went'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'were'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'whatall'      : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'whatever'     : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'whatsoever'   : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'wherewith'    : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'wherewithall' : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'whereas'      : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'whichsoever'  : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'will'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'whosoever'    : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'whomsoever'   : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'whose'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'without'      : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'work'         : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'would'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'worth'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'whenever'     : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'yon'          : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'yonder'       : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'young'        : { 'tag': [  Vocabulary.PORTER ], 'lemma': None },
         'zero'         : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['0']},
         'one'          : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['1']},
         'two'          : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['2']},
         'three'        : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['3']},
         'four'         : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['4']},
         'five'         : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['5']},
         'six'          : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['6']},
         'seven'        : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['7']},
         'eight'        : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['8']},
         'nine'         : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['9']},
         'ten'          : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['10']},
         'eleven'       : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['11']},
         'twelve'       : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['12']},
         'thirteen'     : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['13']},
         'fourteen'     : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['14']},
         'fifteen'      : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['15']},
         'sixteen'      : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['16']},
         'seventeen'    : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['17']},
         'eighteen'     : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['18']},
         'nineteen'     : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['19']},
         'twenty'       : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['20']},
         'thirty'       : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['30']},
         'forty'        : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['40']},
         'fifty'        : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['50']},
         'sixty'        : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['60']},
         'seventy'      : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['70']},
         'eighty'       : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['80']},
         'ninety'       : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['90']},
         'hundred'      : { 'tag': [  Vocabulary.NUMBER, Vocabulary.MUNIT ], 'lemma': ['100']},
         'thousand'     : { 'tag': [  Vocabulary.NUMBER, Vocabulary.MUNIT ], 'lemma': ['1000']},
         'million'      : { 'tag': [  Vocabulary.NUMBER, Vocabulary.MUNIT ], 'lemma': ['1000000']},
         'billion'      : { 'tag': [  Vocabulary.NUMBER, Vocabulary.MUNIT ], 'lemma': ['1000000000']},
         'trillion'     : { 'tag': [  Vocabulary.NUMBER, Vocabulary.MUNIT ], 'lemma': ['1000000000000']},
         'infinity'     : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['infinity']},
         'first'        : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['1']},
         'second'       : { 'tag': [  Vocabulary.NUMBER, Vocabulary.UNIT ], 'lemma': ['2', 'second']},
         'third'        : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['3']},
         'fourth'       : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['4']},
         'fifth'        : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['5']},
         'sixth'        : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['6']},
         'seventh'      : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['7']},
         'eighth'       : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['8']},
         'nineth'       : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['9']},
         'tenth'        : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['10']},
         'elventh'      : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['11']},
         'twelveth'     : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['12']},
         'thirteenth'   : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['13']},
         'fourteenth'   : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['14']},
         'fifteenth'    : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['15']},
         'sixteenth'    : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['16']},
         'seventeenth'  : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['17']},
         'eighteenth'   : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['18']},
         'nineteenth'   : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['19']},
         'twentieth'    : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['20']},
         'thirtieth'    : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['30']},
         'fortieth'     : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['40']},
         'fiftieth'     : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['50']},
         'sextieth'     : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['60']},
         'seventieth'   : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['70']},
         'eightieth'    : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['80']},
         'ninetieth'    : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['90']},
         'hundredth'    : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['100']},
         'thousandth'   : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['1000']},
         'millionth'    : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['1000000']},
         'billionth'    : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['1000000']},
         'trillionth'   : { 'tag': [  Vocabulary.NUMBER ], 'lemma': ['1000000000']},
         'sq'           : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['square']},
         'inch'         : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['inch']},
         'ins'          : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['inch']},
         'ft'           : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['foot']},
         'foot'         : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['foot']},
         'feet'         : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['foot']},
         'yd'           : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['yard']},
         'yds'          : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['yard']},
         'yard'         : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['yard']},
         'mi'           : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['mile']},
         'mile'         : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['mile']},
         'oz'           : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['ounce']},
         'ounce'        : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['ounce']},
         'cup'          : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['cup']},
         'pt'           : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['pint']},
         'pts'          : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['pint']},
         'pint'         : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['pint']},
         'gallon'       : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['gallon']},
         'qt'           : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['quart']},
         'qts'          : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['quart']},
         'quart'        : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['quart']},
         'lb'           : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['pound']},
         'lbs'          : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['pound']},
         'pound'        : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['pound']},
         'ton'          : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['ton']},
         'tons'         : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['ton']},
         'sec'          : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['second']},
         'secs'         : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['second']},
         'min'          : { 'tag': [  Vocabulary.UNIT, Vocabulary.ABBR ], 'lemma': ['minute', 'minimum']},
         'minute'       : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['minute']},
         'hr'           : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['hour']},
         'hrs'          : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['hour']},
         'hour'         : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['hour']},
         'day'          : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['day']},
         'year'         : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['year']},
         'yr'           : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['year']},
         'yrs'          : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['year']},
         'sqft'         : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['square foot']},
         'sf'           : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['square foot']},
         'ft2'          : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['square foot']},
         'ac'           : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['acre']},
         'acre'         : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['acre']},
         'sqmi'         : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['square mile']},
         'mi2'          : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['square mile']},
         'mph'          : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['mile per hour']},
         'tsp'          : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['teaspoon']},
         'teaspoon'     : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['teaspoon']},
         'kn'           : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['knot']},
         'knot'         : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['knot']},
         'mm'           : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['millimeter']},
         'millimeter'   : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['millimeter']},
         'millimetre'   : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['millimeter']},
         'cm'           : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['centimeter']},
         'centimeter'   : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['centimeter']},
         'centimetre'   : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['centimeter']},
         'km'           : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['kilometer']},
         'kilometer'    : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['kilometer']},
         'kilometre'    : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['kilometer']},
         'kmh'          : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['kilometer per hour']},
         'm'            : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['meter']},
         'meter'        : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['meter']},
         'metre'        : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['meter']},
         'ml'           : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['milliliter']},
         'milliliter'   : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['milliliter']},
         'l'            : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['liter']},
         'liter'        : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['liter']},
         'litre'        : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['liter']},
         'g'            : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['gram']},
         'gram'         : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['gram']},
         'mg'           : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['milligram']},
         'milligram'    : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['milligram']},
         'kilo'         : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['kilogram']},
         'kg'           : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['kilogram']},
         'kilogram'     : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['kilogram']},
         'tonne'        : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['tonne']},
         'kw'           : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['kilowatt']},
         'kilowatt'     : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['kilowatt']},
         'sqm'          : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['square meter']},
         'm2'           : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['square meter']},
         'km2'          : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['square kilometer']},
         'm3'           : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['cubic meter']},
         'ha'           : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['hectera']},
         'hectera'      : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['hectera']},
         'kmh'          : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['kilometer per hour']},
         'kwh'          : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['kilowatt per hour']},
         '°f'           : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['fahrenheit']},
         'fahrenheit'   : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['fahrenheit']},
         '°c'           : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['celsius']},
         'celsius'      : { 'tag': [  Vocabulary.UNIT   ], 'lemma': ['celsius']},
         'height'       : { 'tag': [  Vocabulary.MEASUREMENT ], 'lemma': ['height']},
         'ht'           : { 'tag': [  Vocabulary.MEASUREMENT ], 'lemma': ['height']},
         'width'        : { 'tag': [  Vocabulary.MEASUREMENT ], 'lemma': ['width']},
         'length'       : { 'tag': [  Vocabulary.MEASUREMENT ], 'lemma': ['length']},
         'len'          : { 'tag': [  Vocabulary.MEASUREMENT ], 'lemma': ['length']},
         'distance'     : { 'tag': [  Vocabulary.MEASUREMENT ], 'lemma': ['length']},
         'weight'       : { 'tag': [  Vocabulary.MEASUREMENT ], 'lemma': ['weight']},
         'wt'           : { 'tag': [  Vocabulary.MEASUREMENT ], 'lemma': ['weight']},
         'volume'       : { 'tag': [  Vocabulary.MEASUREMENT ], 'lemma': ['volume']},
         'quantity'     : { 'tag': [  Vocabulary.MEASUREMENT ], 'lemma': ['quantity']},
         'deep'         : { 'tag': [  Vocabulary.MEASUREMENT ], 'lemma': ['depth']},
         'depth'        : { 'tag': [  Vocabulary.MEASUREMENT ], 'lemma': ['depth']},
         'speed'        : { 'tag': [  Vocabulary.MEASUREMENT ], 'lemma': ['speed']},
         'velocity'     : { 'tag': [  Vocabulary.MEASUREMENT ], 'lemma': ['speed']},
         'size'         : { 'tag': [  Vocabulary.MEASUREMENT ], 'lemma': ['size']},
         'temp'         : { 'tag': [  Vocabulary.MEASUREMENT ], 'lemma': ['temperature']},
         'temperature'  : { 'tag': [  Vocabulary.MEASUREMENT ], 'lemma': ['temperature']},
         'ave'          : { 'tag': [  Vocabulary.MEASUREMENT ], 'lemma': ['average']},
         'average'      : { 'tag': [  Vocabulary.MEASUREMENT ], 'lemma': ['average']},
         'max'          : { 'tag': [  Vocabulary.MEASUREMENT ], 'lemma': ['maximum']},
         'maximum'      : { 'tag': [  Vocabulary.MEASUREMENT ], 'lemma': ['maximum']},
         'age'          : { 'tag': [  Vocabulary.MEASUREMENT ], 'lemma': ['age']},
         'hwy'          : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['highway']},
         'fwy'          : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['freeway']},
         'pic'          : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['picture']},
         'biz'          : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['business']},
         
         # Stemming Corrections
         'admired'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['admire']},
         'admirably'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['admire']},
         'admirable'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['admire']},
         'advertise'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['advertise']},
         'anesthetize'  : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['anesthetize']},
         'appalled'     : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': ['appall']},
         'authorize'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['authorize']},
         'balanced'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['balance']},
         'balancing'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['balance']},
         'bankrolled'   : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['bankroll']},
         'baptise'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['baptise']},
         'based'        : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['base']},
         'biggest'      : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': ['big']},
         'boating'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['boat']},
         'boring'       : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': ['bore']},
         'bored'        : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': ['bore']},
         'boxer'        : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['boxer']},
         'breaking'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['break']},
         'butterfly'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['butterfly']},
         'changed'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['change']},
         'changer'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['change']},
         'changing'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['change']},
         'chastise'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['chastise']},
         'chilled'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['chill']},
         'climber'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['climb']},
         'computer'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['computer']},
         'consumer'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['consumer']},
         'continued'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['continue']},
         'continuing'   : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['continue']},
         'contributed'  : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['contribute']},
         'combined'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['combine']},
         'crashes'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['crash']},
         'customer'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['customer']},
         'dancing'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['dance']},
         'danced'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['dance']},
         'december'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['december']},
         'desensitize'  : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['desensitize']},
         'dinner'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['dine']},
         'downloader'   : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['download']},
         'downloading'  : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['download']},
         'driven'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['drive']},
         'dumber'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['dumb']},
         'dwarves'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['dwarf']},
         'eclipsed'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['eclipse']},
         'eclipsing'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['eclipse']},
         'elves'        : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['elf']},
         'ending'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['end']},
         'entitled'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['entitle']},
         'equipped'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['equip']},
         'exercises'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['exercise']},
         'exercised'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['exercise']},
         'fantasized'   : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['fantasy']},
         'fishes'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['fish']},
         'floating'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['float']},
         'franchise'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['franchise']},
         'former'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['former']},
         'gender'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['gender']},
         'gone'         : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['go']},
         'halves'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['half']},
         'headquarter'  : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['headquarter']},
         'horribly'     : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': ['horror']},
         'horrify'      : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': ['horror']},
         'included'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['include']},
         'indicated'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['indicate']},
         'inquired'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['inquire']},
         'inquiring'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['inquire']},
         'largest'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['large']},
         'latest'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['late']},
         'latter'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['latter']},
         'lazy'         : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['lazy']},
         'leader'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['lead']},
         'leaves'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['leaf']},
         'legitimize'   : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['legitimate']},
         'letter'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['letter']},
         'licensed'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['license']},
         'licensing'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['license']},
         'liked'        : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['like']},
         'liver'        : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['liver']},
         'loaves'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['loaf']},
         'lover'        : { 'tag': [  Vocabulary.POSITIVE ], 'lemma': ['love']},
         'lovely'       : { 'tag': [  Vocabulary.POSITIVE ], 'lemma': ['love']},
         'manufacturer' : { 'tag': [  Vocabulary.POSITIVE ], 'lemma': ['manufacture']},
         'manufactured' : { 'tag': [  Vocabulary.POSITIVE ], 'lemma': ['manufacture']},
         'merchandise'  : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['merchandise']},
         'misspelled'   : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['misspell']},
         'november'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['november']},
         'october'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['october']},
         'ongoing'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['ongoing']},
         'organize'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['organize']},
         'organized'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['organize']},
         'organizing'   : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['organize']},
         'participates' : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['participate']},
         'permitted'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['permit']},
         'possibly'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['possible']},
         'potatoes'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['potato']},
         'preferred'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['prefer']},
         'produced'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['produce']},
         'promoted'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['promote']},
         'proven'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['prove']},
         'provider'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['provide']},
         'provided'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['provide']},
         'raced'        : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['race']},
         'racing'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['race']},
         'racer'        : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['race']},
         'raster'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['raster']},
         'referred'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['refer']},
         'refined'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['refine']},
         'refining'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['refine']},
         'refiner'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['refine']},
         'relapsing'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['relapse']},
         'roses'        : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['rose']},
         'seawater'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['seawater']},
         'shared'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['share']},
         'sharing'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['share']},
         'stepfamily'   : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['stepfamily']},
         'stupidity'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['stupid']},
         'surprise'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['surprise']},
         'surprised'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['surprise']},
         'surprising'   : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['surprise']},
         'taken'        : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['take']},
         'terribly'     : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': ['terrible']},
         'testify'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['testify']},
         'tinest'       : { 'tag': [  Vocabulary.QUANTIFIER ], 'lemma': ['tiny']},
         'tomatoes'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['tomato']},
         'transfer'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['transfer']},
         'transferrer'  : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['transfer']},
         'treating'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['treat']},
         'treatment'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['treat']},
         'tumbling'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['tumble']},
         'united'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['united']},
         'updated'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['update']},
         'violated'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['violate']},
         'waiver'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['waive']},
         'water'        : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['water']},
         'wharves'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['wharf']},
         'wives'        : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['wife']},
         'wolves'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['wolf']},
         'analyses'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['analyze']},
         'analysis'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['analyze']},
         'maneuver'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['maneuver']},
         'unfavorable'  : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['unfavorable']},
         
         # Common misspelling (or slang)
         'dumbiest'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['dumb']},
         'stupider'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['stupid']},
         'stupidified'  : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['stupid']},  
         'crappy'       : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': ['crap'] },  
         'fulfil'       : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': ['fullfil']},   
         'moslem'       : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': ['muslim']},    
         'guage'        : { 'tag': [  Vocabulary.NEGATIVE ], 'lemma': ['gauge']}, 
         
         # UK Spelling
         'analogue'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['analog']},
         'analyse'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['analyze']},
         'apologise'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['apologize']},
         'apologised'   : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['apologize']},
         'apologising'  : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['apologize']},
         'behaviour'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['behavior']},
         'beyound'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['beyond']},
         'breathalsye'  : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['breathalyze']},
         'catalogue'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['catalog']},
         'centre'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['center']},
         'cheque'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['check']},
         'collectable'  : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['collectible']},
         'colour'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['color']},
         'defence'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['defense']},
         'dialogue'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['dialog']},
         'despatch'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['dispatch']},         
         'dreamt'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['dream']},
         'endeavour'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['endeavor']},
         'oestrogen'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['estrogen']},
         'favour'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['favor']},
         'favourite'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['favorite']},
         'fibre'        : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['fiber']},
         'flavour'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['flavor']},
         'fuelled'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['fuel']},
         'fuelling'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['fuel']},
         'grey'         : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['gray']},
         'harbour'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['harbor']},
         'honour'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['honor']},
         'humour'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['humor']},
         'jewellery'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['jewelery']},
         'labour'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['labor']},
         'leapt'        : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['leap']},
         'leant'        : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['lean']},
         'learnt'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['learn']},
         'leukaemia'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['leukemia']},
         'licence'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['license']},
         'manoeuvre'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['maneuver']},
         'marvellous'   : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['marvelous']},
         'meagre'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['meager']},
         'mediaeval'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['medieval']},
         'neighbour'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['neighbor']},
         'odour'        : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['odor']},
         'organisation' : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['organization']},
         'organise'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['organize']},
         'organised'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['organize']},
         'organising'   : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['organize']},
         'paralyse'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['paralyze']},
         'parlour'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['parlor']},
         'peaditric'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['peditric']},
         'plough'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['plow']},
         'practise'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['practice']},
         'practised'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['practice']},
         'practising'   : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['practice']},
         'pretence'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['pretense']},
         'programme'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['program']},
         'recognise'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['recognize']},
         'recognised'   : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['recognize']},
         'recognising'  : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['recognize']},
         'rumour'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['rumor']},
         'sceptre'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['scepter']},
         'splendour'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['splendor']},
         'succour'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['succor']},
         'theatre'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['theater']},
         'travelled'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['travel']},
         'travelling'   : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['travel']},
         'traveller'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['travel']},
         'vapour'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['vapor']},
         'vigour'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['vigor']},
         'judgement'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['judgment']},
         'candour'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['candor']},
         'aeroplane'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['airplane']},
         'blonde'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['blond']},
         'glamour'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['glamor']},
         'spoilt'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['spoil']},
         'unfavourable' : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['unfavorable']},
         'favourably'   : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['favorably']},
         'counsellor'   : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['counselor']},
         'counselling'  : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['counselor']},
         'draughts'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['checkers']},
         'savour'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['savor']},
         'enamour'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['enamor']},
         'amphitheatre' : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['amphitheater']},
         'spilt'        : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['spill']},
         'rigour'       : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['rigor']},
         'authorise'    : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['authorize']},
         'expence'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['expense']},
         'rancour'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['rancor']},
         'calibre'      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['caliber']},
         'armour '      : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['armor']},
         'armoury '     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['armor']},
         'agonise '     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['agonize']},

         # Scanning Errors
         'reposktory'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['repository']},
         'accesskng'     : { 'tag': [  Vocabulary.UNTAG ], 'lemma': ['access']},
       }
       
if __name__ == "__main__":
    print(vocab['what'])